check_sampling_strategy
=====================================================================

.. currentmodule:: imbalanced_ensemble.utils

.. autofunction:: check_sampling_strategy

.. include:: ../../../back_references/imbalanced_ensemble.utils.check_sampling_strategy.examples

.. raw:: html

    <div style='clear:both'></div>